﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using FT.Architecture.NHibernate.Context;
using FT.Architecture.NHibernate.Factories;
using FT.Architecture.NHibernate.Persistence;
using FT.Architecture.NHibernate.Queries;
using FT.Architecture.NHibernate.Repositories;
using FT.Architecture.NHibernate.SessionManagement;
using FT.Architecture.Persistence;
using FT.Architecture.Queries;
using FT.Architecture.Repositories;
using FT.Architecture.UnitOfWork;
using FT.Architecture.Utils.Log;
using StructureMap.Configuration.DSL;

namespace $rootnamespace$.Container
{
    public class StructureMapRegistry : Registry
    {
        public StructureMapRegistry()
        {
            For<IPersistenceService>().Use<PersistenceService>();
            For<IUnitOfWork>().Singleton().Use<NHibernateUnitOfWork>();
            For<INHibernateConfigurator>().Use<FluentConfigurator>();
            SelectConstructor(() => new SessionProviderService());
            For<ISessionProviderService>().Use<SessionProviderService>();
            For<IQueryExecutorService>().Use<HqlExecutorService>();
            For<ILoggerFactory>().Use<Log4NetLoggerFactory>();

            // Generic repository
            For(typeof(IRepository<>)).Use(typeof(NHibernateRepository<>));

            Scan(x =>
            {
                x.AssemblyContainingType<MyEntity>(); // Please add a reference to your domain assembly
                x.WithDefaultConventions();
            });

            Scan(x =>
            {
                x.AssemblyContainingType<IMyEntityRepository>();
                x.WithDefaultConventions();
            });

            Scan(x =>
            {
                x.AssemblyContainingType<MyEntityRepository>(); // Please add a ref to your data assembly
                x.WithDefaultConventions();
            });

            Scan(x =>
            {
                x.AssemblyContainingType<ILoggerFactory>();
                x.WithDefaultConventions();
            });

            Scan(x =>
            {
                x.AssemblyContainingType<IQueryExecutorService>();
                x.WithDefaultConventions();
            });
        }
    }
}
