using FT.Architecture.Persistence;
using FT.Architecture.UnitOfWork;
using $rootnamespace$.Container;
using StructureMap;

namespace $rootnamespace$
{
    class Program
    {
        static void Main(string[] args)
        {
            Bootstrap.Initialise();

            var runtime = ObjectFactory.GetInstance<Runtime>();

            runtime.Reset(); // Reset the database and creates all tables
            runtime.AddStaticData(); // Adds some static data
            runtime.DisplayAll(); // Display those data
            
            System.Console.Out.WriteLine("--end--");
            System.Console.Read();
        }
    }

    public class Runtime
    {
        private readonly IMyEntityRepository _myEntityRepository;
        private readonly IPersistenceService _persistenceService;
        private readonly IUnitOfWork _unitOfWork;

        public Runtime(IPersistenceService persistenceService,
            IUnitOfWork unitOfWork,
            IMyEntityRepository myEntityRepository)
        {
            _persistenceService = persistenceService;
            _unitOfWork = unitOfWork;
            _myEntityRepository = myEntityRepository;
        }

        public void Reset()
        {
            _persistenceService.BuildPersistence(); // Creates the database table from the NHibernate mapping files automatically
            AddStaticData();
        }

        /// <summary>
        /// Use this to create some data for example
        /// </summary>
        public void AddStaticData()
        {
            _unitOfWork.Start();

            var entity = new MyEntity {Name = "Plop"};

            _myEntityRepository.Save(entity);
            
            _unitOfWork.Commit();
        }

        public void DisplayAll()
        {
            _unitOfWork.Start();

            var allEntities = _myEntityRepository.GetAll();

            foreach (var entity in allEntities)
            {
                System.Console.Out.WriteLine(entity.Name);
            }

            _unitOfWork.Commit();
        }
    }
}
