using System;
using System.Web;
using FT.Architecture.UnitOfWork;
using FT.Architecture.Utils.Log;
using StructureMap;

// This is an example and can be deleted, only usefull for Web Apps
namespace $rootnamespace$.Context
{
    public class NHibernateModule : IHttpModule
    {
        private static bool _startupComplete;
        private static readonly object Lock = new object();
        private ILogger _logger;

        public void Init(HttpApplication context)
        {
            context.BeginRequest += ContextBeginRequest;
            context.EndRequest += ContextEndRequest;
        }

        private void ContextBeginRequest(object sender, EventArgs e)
        {
            Logger.Info("Unit of work context begin");
            EnsureStartup();
            var unitOfWork = ObjectFactory.GetInstance<IUnitOfWork>();
            Logger.Info("Unit of work context begin: unit of work taken " + unitOfWork.GetHashCode());
            //var unitOfWorkManager = ServiceLocator.GetInstance<IUnitOfWork>();
            unitOfWork.Start();

            Logger.Info("Unit of work context begin: unit of work started " + unitOfWork.GetHashCode());
        }

        private void ContextEndRequest(object sender, EventArgs e)
        {
            var unitOfWork = ObjectFactory.GetInstance<IUnitOfWork>();
            Logger.Info("Unit of work context end: unit of work taken " + unitOfWork.GetHashCode());
            unitOfWork.Commit();
            Logger.Info("Unit of work context end: unit of work commited " + unitOfWork.GetHashCode());
        }

        private void EnsureStartup()
        {
            if (!_startupComplete)
            {
                lock (Lock)
                {
                    if (!_startupComplete)
                    {
                        Logger.Info("Unit of work startup");
                        var unitOfWork = ObjectFactory.GetInstance<IUnitOfWork>();
                        unitOfWork.Initialise();
                        _startupComplete = true;
                    }
                }
            }
        }

        private ILogger Logger
        {
            get
            {
                if (_logger == null)
                {
                    var logFactory = ObjectFactory.GetInstance<ILoggerFactory>();
                    _logger = logFactory.Build("NHibernateModule");
                }
                return _logger;
            }
        }

        public void Dispose()
        {
        }
    }
}
