#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion
using FT.Architecture.Utils.Math;

namespace FT.Architecture.Example.Core.Entities.Humans
{
    /// <summary>
    /// Generates <see cref="IHuman"/> entities
    /// </summary>
    public class HumanFactory
    {
        /// <summary>
        /// Get a random <see cref="IHuman"/> entity, with a given father and mother
        /// </summary>
        /// <param name="father"></param>
        /// <param name="mother"></param>
        /// <returns></returns>
        public static IHuman GetRandomHuman(Man father, Woman mother)
        {
            int randomNumber = RandomFactory.Instance.Next(0, 100);

            if (randomNumber < 50)
                return new Man(father, mother);
            
            if (randomNumber < 99)
                return new Woman(father, mother);

            return new Superman(father, mother);
        }

        /// <summary>
        /// Get a random <see cref="IHuman"/> entity, with no parents
        /// </summary>
        /// <returns></returns>
        public static IHuman GetRandomHuman()
        {
            return GetRandomHuman(null, null);
        }
    }
}
