#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion

using System;
using System.Collections.Generic;
using FT.Architecture.Entities;
using FT.Architecture.Example.Core.Entities.Humans;

namespace FT.Architecture.Example.Core.Entities.Pets
{
    /// <summary>
    /// Base class for any Pet
    /// </summary>
    public abstract class PetBase : Entity, IPet
    {
        private string name;
        private readonly ICollection<IHuman> owners;
        private IHuman borrowedBy;

        /// <summary>
        /// Constructor
        /// </summary>
        protected PetBase()
        {
            owners = new List<IHuman>();
        }

        /// <summary>
        /// Name of the pet
        /// </summary>
        public virtual string Name
        {
            get { return name; }
            set { name = value; }
        }

        /// <summary>
        /// Persons who own the <see cref="IPet"/>
        /// </summary>
        public virtual ICollection<IHuman> Owners
        {
            get { return owners; }
        }

        /// <summary>
        /// Person who borrowed the animal
        /// </summary>
        public virtual IHuman BorrowedBy
        {
            get { return borrowedBy; }
            set { borrowedBy = value; }
        }

        /// <summary>
        /// Say something
        /// </summary>
        /// <returns></returns>
        public abstract string SaySomething();
    }
}
