#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion
using System;
using System.Collections.Generic;
using FT.Architecture.Example.Core.Repositories;
using FT.Architecture.Example.Core.Entities.Humans;
using FT.Architecture.Logging;
using FT.Architecture.NHibernate.Repositories;
using FT.Architecture.NHibernate.SessionManagement;
using FT.Architecture.Queries;

namespace FT.Architecture.Example.Data.Repositories
{
    /// <summary>
    /// Implementation of the Human DAL
    /// </summary>
    public class NHibernateHumanRepository : NHibernateRepository<IHuman>, IHumanRepository 
    {
        public NHibernateHumanRepository(ISessionProviderService sessionProvider, IQueryExecutorService queryExecutor, ILogService logService) : base(sessionProvider, queryExecutor, logService)
        {
        }

        /// <summary>
        /// Gets all the humans under 18 years old of age
        /// </summary>
        /// <returns></returns>
        public IList<IHuman> GetUnderAgeHumans()
        {
            return SessionProvider.GetSession().CreateQuery("from IHuman h where h.DateBorn >= :limit")
                .SetDateTime("limit", DateTime.Today.AddYears(-18))
                .List<IHuman>();
        }

        public IList<IHuman> GetHumansOrderedByNameThenTelephone()
        {
            return SessionProvider.GetSession().CreateQuery("from IHuman h order by h.Name asc, h.Telephone desc")
                .List<IHuman>();
        }
    }
}
