﻿using FT.Architecture.Example.Data.Repositories;
using FT.Architecture.NHibernate.Queries;
using FT.Architecture.Queries;
using NUnit.Framework;

namespace FT.Architecture.Tests.Architecture
{
    public class CountByQueryTests : BaseTest
    {
        private NHibernateHumanRepository repository;
        private IQueryExecutorService systemUnderTest;

        public override void SetUp()
        {
            base.SetUp();

            systemUnderTest = new HqlExecutorService(sessionProviderService);
            repository = new NHibernateHumanRepository(sessionProviderService, systemUnderTest, logService);
            unitOfWork.Start();
        }

        [TearDown]
        public void TearDown()
        {
            unitOfWork.Rollback();
        }

        [TestFixture]
        public class When_Counting_Entities_By_Query : CountByQueryTests
        {
            [Test]
            public void The_Method_Should_Return_The_Number_Of_Entities()
            {
                // Arrange
                var referenceResults = repository.GetCount();

                // Act
                var query = repository.CreateQuery();
                var results = repository.CountBy(query);

                // Assert
                Assert.That(referenceResults, Is.EqualTo(results));
            }

            [Test]
            public void It_Should_Not_Fail_When_Containing_Fetches()
            {
                // Arrange
                var referenceResults = repository.GetCount();

                // Act
                var query = repository.CreateQuery();
                query.Fetch(x => x.Father);
                var results = repository.CountBy(query);

                // Assert
                Assert.That(referenceResults, Is.EqualTo(results));
            }
        }
    }
}
