﻿#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion
using FT.Architecture.Example.Core.Entities.Humans;
using FT.Architecture.Example.Core.Entities.Subscriptions;
using NUnit.Framework;

namespace FT.Architecture.Tests.Architecture
{
    [TestFixture]
    public class NonGenericRepositoryTest : BaseTest
    {
        [Test]
        public void TestingTheNonGenericRepository()
        {
            unitOfWork.Start();
            //Check the count in object method
            long genericCount = humanRepository.GetCount();
            long nonGenericCount = nonGenericRepository.CountInObject("", "Name", typeof(IHuman).FullName);
            Assert.AreEqual(genericCount, nonGenericCount);

            //Check the GetAll
            var genericAll = subscriptionRepository.GetAll();
            var nonGenericAll = nonGenericRepository.GetAll(typeof(Subscription));
            Assert.AreEqual(genericAll.Count, nonGenericAll.Count);

            //Check the GetById
            var genericById = humanRepository.GetRandom();
            var nonGenericById = nonGenericRepository.GetById(genericById.Id, typeof(IHuman));
            Assert.AreEqual(genericById, nonGenericById);

            //Check the get by member
            var genericByMember = humanRepository.GetRandom();
            var nonGenericByMember = nonGenericRepository.GetByMember(genericByMember.Id, "Id",
                                                                                typeof(IHuman));
            Assert.AreEqual(genericByMember, nonGenericByMember);
            unitOfWork.Commit();
        }

        [Test]
        public void TestingTheSearchInObjectMethod()
        {
            unitOfWork.Start();
            var returnedObjects = nonGenericRepository.SearchInObject(
                "Ant%",
                "Name",
                "Name",
                "Name",
                "desc",
                typeof(IHuman).FullName,
                0,
                10
                );

            Assert.LessOrEqual(returnedObjects.Count, 10);

            foreach (IHuman human in returnedObjects)
            {
                Assert.IsTrue(human.Name.StartsWith("Ant"));
            }
            unitOfWork.Commit();
        }

        [Test]
        public void TestUnProxy()
        {
            unitOfWork.Start();
            IHuman human;

            do
            {
                human = humanRepository.GetRandom();
            } while (human.Father == null);

            var proxy = human.Father;
            var nonProxy = nonGenericRepository.UnProxy(proxy);

            //One is a proxy, the other one is not
            Assert.AreEqual(proxy, nonProxy); //Equals() should say yes
            unitOfWork.Commit();
        }

        [Test]
        public void TestGetCount()
        {
            unitOfWork.Start();

            long countByRepository = humanRepository.GetCount();
            long countByNonGenericRepository = nonGenericRepository.GetCount(typeof(IHuman));

            unitOfWork.Rollback();

            Assert.That(countByRepository, Is.EqualTo(countByNonGenericRepository));
        }

        [Test]
        public void TestGetRandom()
        {
            unitOfWork.Start();

            var random = nonGenericRepository.GetRandom(typeof(IHuman));

            unitOfWork.Rollback();

            Assert.That(random, Is.Not.Null);
        }
    }
}
