﻿using FT.Architecture.Example.Core.Entities.Pets;
using FT.Architecture.NHibernate.Repositories;
using FT.Architecture.NHibernate.SessionManagement;
using NUnit.Framework;
using Rhino.Mocks;

namespace FT.Architecture.Tests.Architecture
{
    [TestFixture]
    public class RepositoryServiceTests : BaseTest
    {
        [Test]
        public void RepositoryServiceGivesCorrectImplementationOfNonGenericRepository()
        {
            // Arrange
            var sessionProvider = MockRepository.GenerateStub<ISessionProviderService>();
            var repositoryService = new NHibernateRepositoryService(sessionProvider, null, logService);

            // Act
            var repository = repositoryService.GetRepository();

            // Assert
            Assert.That(repository, Is.TypeOf<NHibernateNonGenericRepository>());
        }

        [Test]
        public void RepositoryServiceGivesCorrectImplementationOfGenericRepository()
        {
            // Arrange
            var sessionProvider = MockRepository.GenerateStub<ISessionProviderService>();
            var repositoryService = new NHibernateRepositoryService(sessionProvider, null, logService);

            // Act
            var repository = repositoryService.GetRepository<Cat, long>();

            // Assert
            Assert.That(repository, Is.TypeOf<NHibernateGenericRepository<Cat, long>>());
        }

        [Test]
        public void RepositoryServiceGivesCorrectImplementationOfRepository()
        {
            // Arrange
            var sessionProvider = MockRepository.GenerateStub<ISessionProviderService>();
            var repositoryService = new NHibernateRepositoryService(sessionProvider, null, logService);

            // Act
            var repository = repositoryService.GetRepository<Cat>();

            // Assert
            Assert.That(repository, Is.TypeOf<NHibernateRepository<Cat>>());
        }
    }
}
