﻿using FT.Architecture.NHibernate.SessionManagement;
using NHibernate;
using NUnit.Framework;
using Rhino.Mocks;

namespace FT.Architecture.Tests.Architecture
{
    [TestFixture]
    public class SessionProviderServiceTests
    {
        private ISessionProviderService systemUnderTest;

        [SetUp]
        public void SetUp()
        {
            systemUnderTest = new SessionProviderService();
            systemUnderTest.SetSession(null);
        }

        [Test]
        public void SessionProviderShouldThrowAnExceptionIfSessionIsNotSet()
        {
            // Arrange
            // Don't set any session

            // Act & Assert
            Assert.That(() => systemUnderTest.GetSession(), Throws.Exception.TypeOf<SessionProviderException>());
        }

        [Test]
        public void SessionProviderShouldReturnTheSessionItWasGiven()
        {
            // Arrange
            var mockSession = MockRepository.GenerateStub<ISession>();
            systemUnderTest.SetSession(mockSession);

            // Act
            var retrievedSession = systemUnderTest.GetSession();

            // Assert
            Assert.That(retrievedSession, Is.SameAs(mockSession));
        }

        [Test]
        public void SessionProviderShouldNotAcceptToSetTwoDifferentSessionsInARow()
        {
            // Arrange
            var mockSession1 = MockRepository.GenerateStub<ISession>();
            var mockSession2 = MockRepository.GenerateStub<ISession>();
            systemUnderTest.SetSession(mockSession1);

            // Act
            Assert.That(() => systemUnderTest.SetSession(mockSession2), Throws.Exception.TypeOf<SessionProviderException>());
        }

        [Test]
        public void SessionProviderShouldThrowAnExceptionWhenSessionSetToNullAndRetrieved()
        {
            // Arrange
            var mockSession = MockRepository.GenerateStub<ISession>();
            systemUnderTest.SetSession(mockSession);
            systemUnderTest.SetSession(null);

            // Act & Assert
            Assert.That(() => systemUnderTest.GetSession(), Throws.Exception.TypeOf<SessionProviderException>());
        }
    }
}
