﻿#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion
using System;
using FT.Architecture.Example.Core.Entities.Humans;
using FT.Architecture.Example.Core.Entities.Subscriptions;
using NUnit.Framework;

namespace FT.Architecture.Tests.Architecture
{
    [TestFixture]
    public class TransientAndPersistentEqualityTests
    {
        [Test]
        public void TestingTwoTransientThatShouldBeTheSame()
        {
            //According to the IHuman interface, a IHuman who is transient is identified by 3 business values:
            //  - Name
            //  - DoB
            //  - Telephone
            //If two IHuman have all those properties equal, they are considered to be the same

            IHuman human1 = new Man();
            human1.Name = "Jean-Luc";
            human1.DateBorn = new DateTime(1982, 11, 1);
            human1.Telephone = "01 43 28 99 67";

            IHuman human2 = new Man();
            human2.Name = "Jean-Luc";
            human2.DateBorn = new DateTime(1982, 11, 1);
            human2.Telephone = "01 43 28 99 67";

            Assert.AreEqual(human1, human2, "These two should be considered equals");

            //As the property CV is not counted as a business key, they should still be equal
            human2.CV = "A different CV from human 1";
            Assert.AreEqual(human1, human2, "These two should still be considered equals");

            //Telephone is on the other hand a BK, so changing it makes them unequal
            human2.Telephone = "01 30 82 20 23";
            Assert.AreNotEqual(human1, human2, "These two should NOT be considered equals");

            //We simulate saving human1 on the DB by assigning a non zero ID
            human1.Id = 1;
            Assert.AreNotEqual(human1, human2, "These two should NOT be considered equals");

            //We simulate saving human2 on the DB by assigning an ID, but a different one
            human2.Id = 2;
            Assert.AreNotEqual(human1, human2, "These two should NOT be considered equals");

            //We simulate the DB having the same ID on both
            human2.Id = 1;
            Assert.AreEqual(human1, human2, "These two should still be considered equals");
        }

        [Test]
        public void TestingTwoTransientWithCompositeIdsThatShouldBeTheSame()
        {
            //According to the IHuman interface, a IHuman who is transient is identified by 3 business values:
            //  - Name
            //  - DoB
            //  - Telephone
            //If two IHuman have all those properties equal, they are considered to be the same

            IHuman human = new Man();
            human.Name = "Jean-Luc";
            human.DateBorn = new DateTime(1982, 11, 1);
            human.Telephone = "01 43 28 99 67";

            Subscription sub1 = new Subscription();
            sub1.Id.Human = human;
            sub1.Id.Type = SubscriptionType.Electricity;
            sub1.MonthlyPrice = 123;
            sub1.SubscribedOn = new DateTime(1900,1,1);
            sub1.FinishOn = new DateTime(2000,1,1);

            Subscription sub2 = new Subscription();
            sub2.Id.Human = human;
            sub2.Id.Type = SubscriptionType.Electricity;
            sub2.MonthlyPrice = 123;
            sub2.SubscribedOn = new DateTime(1900, 1, 1);
            sub2.FinishOn = new DateTime(2000, 1, 1);
            

            Assert.AreEqual(sub1, sub2, "These two should be considered equals");

            //As the property MonthlyPrice is not counted as a business key, they should still be equal
            sub1.MonthlyPrice = 456;
            Assert.AreEqual(sub1, sub2, "These two should still be considered equals");

            //Type is on the other hand a BK, so changing it makes them unequal
            sub2.Id.Type = SubscriptionType.Television;
            Assert.AreNotEqual(sub1, sub2, "These two should NOT be considered equals");
        }
    }
}
