﻿#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion
using System;
using FT.Architecture.Example.Core.Repositories;
using FT.Architecture.Example.Core.Entities.Humans;
using NUnit.Framework;

namespace FT.Architecture.Tests.Architecture
{
    [TestFixture]
    public class TypesAndProxiesTests : BaseTest
    {
        /// <summary>
        /// Check that GetType() always return a type that is the real type, not a proxy
        /// </summary>
        [Test]
        public void TestProxies()
        {
            unitOfWork.Start();
            IHuman human;

            do
            {
                human = humanRepository.GetRandom();
            }
            while (human.Father == null);

            var proxy = human.Father;
            var nonProxy = humanRepository.UnProxy(humanRepository.GetByMember(x => x.Id, proxy.Id));

            Type typeProxy = proxy.GetType(); //That should use the "new" method on BaseObject, which should bypass the proxy
            Type typeNonProxy = nonProxy.GetType(); //Normal type (as this is not a proxy)

            Assert.AreEqual(typeProxy, typeNonProxy);

            unitOfWork.Commit();
        }

        [Test]
        public void The_Object_Is_Not_A_Proxy()
        {
            // Arrange
            var man = new Man();

            // Act
            var unProxied = humanRepository.UnProxy(man);

            // Assert
            Assert.That(unProxied, Is.EqualTo(man));
        }
    }
}
