﻿#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion

using FT.Architecture.Entities;
using NUnit.Framework;

namespace FT.Architecture.Tests.Architecture
{
    [TestFixture]
    public class UnderlyingStorageTest : BaseTest
    {
        [Test]
        public void TestFromEntityToTableRegularMember()
        {
            unitOfWork.Start();
            StorageInfo? storageInfo = dogRepository.UnderlyingStorage.GetStorageInfo(d => d.Name);

            Assert.IsNotNull(storageInfo);
            Assert.AreEqual("dbo.pet", storageInfo.Value.TableName);
            Assert.AreEqual("Name", storageInfo.Value.ColumnName);
            unitOfWork.Rollback();
        }

        [Test]
        public void TestFromEntityToTableEntityMember()
        {
            unitOfWork.Start();
            StorageInfo? storageInfo = supermanRepository.UnderlyingStorage.GetStorageInfo(d => d.Father);

            Assert.IsNotNull(storageInfo);
            Assert.AreEqual("dbo.human", storageInfo.Value.TableName);
            Assert.AreEqual("ID_Father", storageInfo.Value.ColumnName);
            unitOfWork.Rollback();
        }

        [Test]
        public void TestFromEntityToTableIDMember()
        {
            unitOfWork.Start();
            StorageInfo? storageInfo = dogRepository.UnderlyingStorage.GetStorageInfo(d => d.Id);

            Assert.IsNotNull(storageInfo);
            Assert.AreEqual("dbo.pet", storageInfo.Value.TableName);
            Assert.AreEqual("ID_Pet", storageInfo.Value.ColumnName);
            unitOfWork.Rollback();
        }

        [Test]
        public void TestFromEntityToTableRegularMemberWithColumnDifferentName()
        {
            unitOfWork.Start();
            StorageInfo? storageInfo = supermanRepository.UnderlyingStorage.GetStorageInfo(d => d.Telephone);

            Assert.IsNotNull(storageInfo);
            Assert.AreEqual("dbo.human", storageInfo.Value.TableName);
            Assert.AreEqual("PhoneNumber", storageInfo.Value.ColumnName);
            unitOfWork.Rollback();
        }

        [Test]
        public void TestFromEntityToTableRegularMemberNotMapped()
        {
            unitOfWork.Start();
            StorageInfo? storageInfo = supermanRepository.UnderlyingStorage.GetStorageInfo(d => d.Age);

            Assert.IsNull(storageInfo);
            unitOfWork.Rollback();
        }

        [Test]
        public void TestFromTableToEntityRegularMember()
        {
            unitOfWork.Start();
            var entityInfo = dogRepository.UnderlyingStorage.GetEntityInfo("Name");

            Assert.IsNotNull(entityInfo);
            Assert.AreEqual("Dog", entityInfo.Value.EntityType.Name);
            Assert.AreEqual("Name", entityInfo.Value.EntityMember.Name);
            unitOfWork.Rollback();
        }

        [Test]
        public void TestFromTableToEntityeIDMember()
        {
            unitOfWork.Start();
            var entityInfo = dogRepository.UnderlyingStorage.GetEntityInfo("ID_Pet");

            Assert.IsNotNull(entityInfo);
            Assert.AreEqual("Dog", entityInfo.Value.EntityType.Name);
            Assert.AreEqual("Id", entityInfo.Value.EntityMember.Name);
            unitOfWork.Rollback();
        }

        [Test]
        public void TestFromTableToEntityRegularMemberWithColumnDifferentName()
        {
            unitOfWork.Start();
            var entityInfo = supermanRepository.UnderlyingStorage.GetEntityInfo("PhoneNumber");

            Assert.IsNotNull(entityInfo);
            Assert.AreEqual("Superman", entityInfo.Value.EntityType.Name);
            Assert.AreEqual("Telephone", entityInfo.Value.EntityMember.Name);
            unitOfWork.Rollback();
        }

        [Test]
        public void TestFromTableToEntityRegularMemberNotMapped()
        {
            unitOfWork.Start();
            var entityInfo = supermanRepository.UnderlyingStorage.GetEntityInfo("Age");

            Assert.IsNull(entityInfo);
            unitOfWork.Rollback();
        }
    }
}

