﻿#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion

using System;
using FT.Architecture.Example.Core.Entities;
using FT.Architecture.Example.Core.Entities.Cars;
using FT.Architecture.Example.Core.Entities.Humans;
using FT.Architecture.Example.Core.Entities.Pets;
using FT.Architecture.Example.Core.Entities.Subscriptions;
using FT.Architecture.Example.Core.Repositories;
using FT.Architecture.Example.Data.Repositories;
using FT.Architecture.Logging;
using FT.Architecture.NHibernate.Context;
using FT.Architecture.NHibernate.Factories;
using FT.Architecture.NHibernate.Persistence;
using FT.Architecture.NHibernate.Repositories;
using FT.Architecture.NHibernate.SessionManagement;
using FT.Architecture.Persistence;
using FT.Architecture.Repositories;
using FT.Architecture.UnitOfWork;
using FT.Architecture.Utils.Log;
using NUnit.Framework;

namespace FT.Architecture.Tests
{
    public class BaseTest
    {
        protected IUnitOfWork unitOfWork;
        protected IUnitOfWork statelessUnitOfWork;
        protected IRepository<Man> manRepository;
        protected IHumanRepository humanRepository;
        protected ISupermanRepository supermanRepository;
        protected IRepository<Dog> dogRepository;
        protected IRepository<Woman> womanRepository;
        protected IPetRepository petRepository;
        protected IRepository<ICanSpeak> canSpeakRepository;
        protected IGenericRepository<Subscription, SubscriptionId> subscriptionRepository;
        protected INonGenericRepository nonGenericRepository;
        protected ISessionProviderService sessionProviderService;
        protected IPersistenceService persistenceService;
        protected IGenericRepository<ICar, Guid> carRepository;
        protected ILogService logService;

        [SetUp]
        public virtual void SetUp()
        {
            logService = new LogService(new Log4NetLoggerFactory());
            sessionProviderService = new SessionProviderService();
            unitOfWork = new NHibernateUnitOfWork(sessionProviderService, new XmlMappingNHibernateConfigurator());
            statelessUnitOfWork = new NHibernateStatelessUnitOfWork(sessionProviderService, new XmlMappingNHibernateConfigurator());
            manRepository = new NHibernateRepository<Man>(sessionProviderService, null, logService);
            humanRepository = new NHibernateHumanRepository(sessionProviderService, null, logService);
            supermanRepository = new NHibernateSupermanRepository(sessionProviderService, null, logService);
            dogRepository = new NHibernateRepository<Dog>(sessionProviderService, null, logService);
            womanRepository = new NHibernateRepository<Woman>(sessionProviderService, null, logService);
            petRepository = new NHibernatePetRepository(sessionProviderService, null, logService);
            canSpeakRepository = new NHibernateRepository<ICanSpeak>(sessionProviderService, null, logService);
            subscriptionRepository = new NHibernateGenericRepository<Subscription, SubscriptionId>(sessionProviderService, null, logService);
            nonGenericRepository = new NHibernateNonGenericRepository(sessionProviderService, logService);
            carRepository = new NHibernateGenericRepository<ICar, Guid>(sessionProviderService, null, logService);
            persistenceService = new PersistenceService(new XmlMappingNHibernateConfigurator());
            unitOfWork.Initialise();
        }
    }
}
