﻿#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion
using System;
using System.Collections.Generic;
using FT.Architecture.Example.Core.Engines;
using FT.Architecture.Example.Core.Entities.Humans;
using FT.Architecture.Repositories;
using NUnit.Framework;

namespace FT.Architecture.Tests
{
    [SetUpFixture]
    public class Init : BaseTest
    {
        /// <summary>
        /// Set up before any test: check whether the database is properly setup. If not, tries to create fake data and schema on it.
        /// </summary>
        [SetUp]
        public override void SetUp()
        {
            base.SetUp();
            SetUpDatabase(Constants.DefaultUnitOfWorkConfig);
        }

        public void SetUpDatabase(string configuration)
        {
            // Checking whether a test DB exists
            bool databaseReady = true;

            unitOfWork.Start();
            try
            {
                IList<Superman> supermans = supermanRepository.GetAll();
                if (supermans.Count == 0)
                    databaseReady = false;
            }
            catch (Exception)
            {
                databaseReady = false;
            }
            unitOfWork.Rollback();

            if (!databaseReady)
            {
                unitOfWork.Start();
                persistenceService.BuildPersistence();
                unitOfWork.Commit();

                unitOfWork.Start();
                var generator = new DatabaseGenerator(unitOfWork, humanRepository, petRepository, carRepository, subscriptionRepository);
                generator.Generate(10);
                unitOfWork.Commit();
            }
        }
    }
}
