﻿using System.Linq;
using FT.Architecture.Example.Core.Entities.Humans;
using FT.Architecture.Queries;
using FT.Architecture.Utils.Reflection;
using NUnit.Framework;

namespace FT.Architecture.Tests.Unit.Queries
{
    public class QueryTests : BaseTest
    {
        [TestFixture]
        public class When_Sorting_A_Query : QueryTests
        {
            [Test]
            public void A_Single_Order_Clause_Should_Give_One_Item()
            {
                // Arrange
                Query<IHuman> query = new Query<IHuman>();
                query.Sort.By(x => x.Name).Ascending();

                // Assert
                Assert.That(query.Sort.Items.Count, Is.EqualTo(1));
                Assert.That(query.Sort.Items.First().SortOrder, Is.EqualTo(SortOrder.Ascending));
                Assert.That(query.Sort.Items.First().SortMember.GetCombinedProperty(), Is.EqualTo("Name"));
            }

            [Test]
            public void A_Double_Order_Clause_Should_Give_Two_Item()
            {
                // Arrange
                Query<IHuman> query = new Query<IHuman>();
                query.Sort.By(x => x.Name).Ascending()
                          .And(x => x.Telephone).Descending();

                // Assert
                Assert.That(query.Sort.Items.Count, Is.EqualTo(2));
                Assert.That(query.Sort.Items.First().SortOrder, Is.EqualTo(SortOrder.Ascending));
                Assert.That(query.Sort.Items.First().SortMember.GetCombinedProperty(), Is.EqualTo("Name"));
                Assert.That(query.Sort.Items.Skip(1).First().SortOrder, Is.EqualTo(SortOrder.Descending));
                Assert.That(query.Sort.Items.Skip(1).First().SortMember.GetCombinedProperty(), Is.EqualTo("Telephone"));
            }

            [Test]
            public void A_Single_Order_Clause_Should_Give_One_Item_2()
            {
                // Arrange
                Query<IHuman> query = new Query<IHuman>();
                query.Sort.By(x => x.Name, SortOrder.Ascending);

                // Assert
                Assert.That(query.Sort.Items.Count, Is.EqualTo(1));
                Assert.That(query.Sort.Items.First().SortOrder, Is.EqualTo(SortOrder.Ascending));
                Assert.That(query.Sort.Items.First().SortMember.GetCombinedProperty(), Is.EqualTo("Name"));
            }

            [Test]
            public void A_Double_Order_Clause_Should_Give_Two_Item_2()
            {
                // Arrange
                Query<IHuman> query = new Query<IHuman>();
                query.Sort.By(x => x.Name, SortOrder.Ascending)
                          .And(x => x.Telephone, SortOrder.Descending);

                // Assert
                Assert.That(query.Sort.Items.Count, Is.EqualTo(2));
                Assert.That(query.Sort.Items.First().SortOrder, Is.EqualTo(SortOrder.Ascending));
                Assert.That(query.Sort.Items.First().SortMember.GetCombinedProperty(), Is.EqualTo("Name"));
                Assert.That(query.Sort.Items.Skip(1).First().SortOrder, Is.EqualTo(SortOrder.Descending));
                Assert.That(query.Sort.Items.Skip(1).First().SortMember.GetCombinedProperty(), Is.EqualTo("Telephone"));
            }
        }
    }
}
