﻿#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion
using System;
using System.Collections.Generic;
using System.Reflection;
using FT.Architecture.Utils.Reflection;
using NUnit.Framework;

namespace FT.Architecture.Tests.Utils
{
    [TestFixture]
    public class AttributeReflectionTest
    {
        [Test]
        public void TestingAttributeFetchingNoInheritance()
        {
            Parent parent = new Parent();
            Child child = new Child();

            IList<PropertyInfo> properties = Attributes.GetPropertiesWithAttribute<AttributeTestAttribute>(parent);
            Assert.AreEqual(3, properties.Count);
            Assert.IsTrue(Contains(properties, "Name"));
            Assert.IsTrue(Contains(properties, "Address"));
            Assert.IsTrue(Contains(properties, "SomePrivateProperty"));

            properties = Attributes.GetPropertiesWithAttribute<AttributeTestAttribute>(child,false);
            Assert.AreEqual(1, properties.Count);
            Assert.IsTrue(Contains(properties, "Telephone"));

            properties = Attributes.GetPropertiesWithAttribute<AttributeTestAttribute>(child, true);
            Assert.AreEqual(6, properties.Count);
            Assert.IsTrue(Contains(properties, "ID"));
            Assert.IsTrue(Contains(properties, "Telephone"));
            Assert.IsTrue(Contains(properties, "Name"));
            Assert.IsTrue(Contains(properties, "Address"));
            Assert.IsTrue(Contains(properties, "SomePrivateProperty"));

        }

        private bool Contains(IList<PropertyInfo> properties, string propertyName)
        {
            foreach (PropertyInfo property in properties)
            {
                if (property.Name == propertyName)
                    return true;
            }

            return false;
        }
    }

    public interface ISampleInterface
    {
        [AttributeTest]
        long ID { get; set; }
    }
 

    public class Parent : ISampleInterface
    {
        [AttributeTest]
        public virtual string Name { get; set; }

        [AttributeTest]
        public virtual string Address { get; set; }

        public virtual string Telephone { get; set; }

        public virtual int Age { get; set; }
        public long ID { get; set; }

        [AttributeTest]
        private string SomePrivateProperty { get; set; }        
    }

    public class Child : Parent
    {
        public override string Name { get; set; }

        [AttributeTest]
        public override string Telephone { get; set; }
    }

    [AttributeUsage(AttributeTargets.Property,AllowMultiple = false, Inherited = true)]
    public class AttributeTestAttribute : Attribute
    {
        
    }
}
