﻿using System;
using FT.Architecture.Utils.ExtensionMethods;
using NUnit.Framework;

namespace FT.Architecture.Tests.Utils.Extensions
{
    public class AppDomainExtensionsTests
    {
        [TestFixture]
        public class When_Getting_Loaded_And_Referenced_Assemblies : AppDomainExtensionsTests
        {
            [Test]
            public void Only_Assemblies_Matching_The_Predicate_Should_Be_Found()
            {
                // Arrange
                var appDomain = AppDomain.CurrentDomain;

                // Act
                var assemblies = AppDomainExtensions.GetLoadedAndReferencedAssemblies(appDomain, name => name.Name.Contains("Tests"));

                // Assert
                Assert.That(assemblies, Is.Not.Empty);
                foreach (var assembly in assemblies)
                {
                    Assert.That(assembly.FullName.Contains("Tests"), Is.True);
                }
            }

            [Test]
            public void All_Assemblies_Should_Be_Found()
            {
                // Arrange
                var appDomain = AppDomain.CurrentDomain;

                // Act
                var assemblies = AppDomainExtensions.GetLoadedAndReferencedAssemblies(appDomain);

                // Assert
                Assert.That(assemblies, Is.Not.Empty);
                Assert.That(assemblies, Has.Count.GreaterThan(80));
            }
        }
    }
}
