﻿using System;
using System.Linq.Expressions;
using FT.Architecture.Utils.Reflection;
using NUnit.Framework;

namespace FT.Architecture.Tests.Utils.Extensions
{
    public class ExpressionExtensionsTests : BaseTest
    {
        [TestFixture]
        public class When_Getting_A_Lambda_Expression_From_A_Property_Name : ExpressionExtensionsTests
        {
            [Test]
            public void An_Integer_Property_Should_Return_The_Correct_Lambda_Expression()
            {
                // Arrange
                Expression<Func<TestClass, object>> expression = x => x.IntTestProperty;

                // Act
                var result = ExpressionsExtensions.GetLambdaExpressionFor<TestClass>("IntTestProperty");

                // Assert
                var resultPropertyName = Reflection.GetCombinedProperty(result);
                var expressionPropertyName = Reflection.GetCombinedProperty(expression);
                Assert.That(resultPropertyName, Is.EqualTo(expressionPropertyName));
                Assert.That(resultPropertyName, Is.EqualTo("IntTestProperty"));
            }

            [Test]
            public void A_String_Property_Should_Return_The_Correct_Lambda_Expression()
            {
                // Arrange
                Expression<Func<TestClass, object>> expression = x => x.StringTestProperty;

                // Act
                var result = ExpressionsExtensions.GetLambdaExpressionFor<TestClass>("StringTestProperty");

                // Assert
                var resultPropertyName = Reflection.GetCombinedProperty(result);
                var expressionPropertyName = Reflection.GetCombinedProperty(expression);
                Assert.That(resultPropertyName, Is.EqualTo(expressionPropertyName));
                Assert.That(resultPropertyName, Is.EqualTo("StringTestProperty"));
            }

            [Test]
            public void An_Object_Property_Should_Return_The_Correct_Lambda_Expression()
            {
                // Arrange
                Expression<Func<TestClass, object>> expression = x => x.ObjectTestProperty;

                // Act
                var result = ExpressionsExtensions.GetLambdaExpressionFor<TestClass>("ObjectTestProperty");

                // Assert
                var resultPropertyName = Reflection.GetCombinedProperty(result);
                var expressionPropertyName = Reflection.GetCombinedProperty(expression);
                Assert.That(resultPropertyName, Is.EqualTo(expressionPropertyName));
                Assert.That(resultPropertyName, Is.EqualTo("ObjectTestProperty"));
            }

            [Test]
            public void An_Enum_Property_Should_Return_The_Correct_Lambda_Expression()
            {
                // Arrange
                Expression<Func<TestClass, object>> expression = x => x.EnumTestProperty;

                // Act
                var result = ExpressionsExtensions.GetLambdaExpressionFor<TestClass>("EnumTestProperty");

                // Assert
                var resultPropertyName = Reflection.GetCombinedProperty(result);
                var expressionPropertyName = Reflection.GetCombinedProperty(expression);
                Assert.That(resultPropertyName, Is.EqualTo(expressionPropertyName));
                Assert.That(resultPropertyName, Is.EqualTo("EnumTestProperty"));
            }
        }

        public class TestClass
        {
            public int IntTestProperty { get; set; }
            
            public string StringTestProperty { get; set; }

            public object ObjectTestProperty { get; set; }

            public TestEnum EnumTestProperty { get; set; }
        }

        public enum TestEnum
        {
            Value1,
            Value2
        }
    }
}
