﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using System.Text;
using FT.Architecture.Utils.ExtensionMethods;
using NUnit.Framework;

namespace FT.Architecture.Tests.Utils.Extensions
{
    public class TypeExtensionsTests
    {
        [TestFixture]
        public class When_Checking_That_A_Type_Is_Of_Another_Type : TypeExtensionsTests
        {
            [Test]
            public void A_Concrete_Class_Of_An_Interface_Should_Match()
            {
                // Act
                bool isOfType = typeof(AConcreteClass).Is<IAnInterface>();

                // Assert
                Assert.That(isOfType, Is.True);
            }

            [Test]
            public void An_Abstract_Class_Of_An_Interface_Should_Match()
            {
                // Act
                bool isOfType = typeof(ABaseImplementation).Is<IAnInterface>();

                // Assert
                Assert.That(isOfType, Is.True);
            }

            [Test]
            public void An_Concrete_Class_Of_A_Base_Class_Should_Match()
            {
                // Act
                bool isOfType = typeof(AConcreteClass).Is<ABaseImplementation>();

                // Assert
                Assert.That(isOfType, Is.True);
            }

            [Test]
            public void An_Concrete_Class_Of_A_Base_Class_The_Wrong_Way_Around_Shouldnt_Match()
            {
                // Act
                bool isOfType = typeof(ABaseImplementation).Is<AConcreteClass>();

                // Assert
                Assert.That(isOfType, Is.False);
            }

            [Test]
            public void A_Concrete_Class_Of_An_Other_Interface_Should_Match()
            {
                // Act
                bool isOfType = typeof(AConcreteClass).Is<IEquatable<AConcreteClass>>();

                // Assert
                Assert.That(isOfType, Is.True);
            }

            [Test]
            public void A_Base_Concrete_Class_Not_Implementing_An_Interface_Should_Not_Match()
            {
                // Act
                bool isOfType = typeof(ABaseImplementation).Is<IEquatable<AConcreteClass>>();

                // Assert
                Assert.That(isOfType, Is.False);
            }
        }

        public interface IAnInterface
        {
        }

        public class ABaseImplementation : IAnInterface
        {
        }

        public class AConcreteClass : ABaseImplementation, IEquatable<AConcreteClass>
        {
            public bool Equals(AConcreteClass other)
            {
                throw new NotImplementedException();
            }
        }
    }
}
