﻿#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion
using System;
using FT.Architecture.Entities;
using NUnit.Framework;

namespace FT.Architecture.Tests.Utils
{
    [TestFixture]
    public class IdParserTest
    {
        [Test]
        public void TestingPrimitives()
        {
            const long id1 = 123;
            string id1Serialised = IdParser.ToString(id1);
            long id1Deserialised = IdParser.FromString<long>(id1Serialised);
            Assert.AreEqual(id1, id1Deserialised);

            const int id2 = 123;
            string id2Serialised = IdParser.ToString(id2);
            int id2Deserialised = IdParser.FromString<int>(id2Serialised);
            Assert.AreEqual(id2, id2Deserialised);

            const string id3 = "123";
            string id3Serialised = IdParser.ToString(id3);
            string id3Deserialised = IdParser.FromString<string>(id3Serialised);
            Assert.AreEqual(id3, id3Deserialised);

            const decimal id4 = 123;
            string id4Serialised = IdParser.ToString(id4);
            decimal id4Deserialised = IdParser.FromString<decimal>(id4Serialised);
            Assert.AreEqual(id4, id4Deserialised);

            const double id5 = 123;
            string id5Serialised = IdParser.ToString(id5);
            double id5Deserialised = IdParser.FromString<double>(id5Serialised);
            Assert.AreEqual(id5, id5Deserialised);

            DateTime id6 = DateTime.Now;
            string id6Serialised = IdParser.ToString(id6);
            DateTime id6Deserialised = IdParser.FromString<DateTime>(id6Serialised);
            Assert.AreEqual(id6, id6Deserialised);
        }

        [Test]
        public void TestComplexIds()
        {
            ComplexIdStruct id1 = new ComplexIdStruct("Antoine","Jaussoin");
            string id1Serialised = IdParser.ToString(id1);
            ComplexIdStruct id1Deserialised = IdParser.FromString<ComplexIdStruct>(id1Serialised);
            Assert.AreEqual(id1, id1Deserialised);

            ComplexIdClass id2 = new ComplexIdClass("Antoine", "Jaussoin");
            string id2Serialised = IdParser.ToString(id2);
            ComplexIdClass id2Deserialised = IdParser.FromString<ComplexIdClass>(id2Serialised);
            Assert.AreEqual(id2, id2Deserialised);
        }

        [Serializable]
        public struct ComplexIdStruct
        {
            private readonly string _firstName;
            private readonly string _lastName;

            public ComplexIdStruct(string firstName, string lastName)
            {
                _firstName = firstName;
                _lastName = lastName;
            }

            public string FirstName
            {
                get { return _firstName; }
            }

            public string LastName
            {
                get { return _lastName; }
            }
        }

        [Serializable]
        public class ComplexIdClass
        {
            private readonly string _firstName;
            private readonly string _lastName;

            public ComplexIdClass(string firstName, string lastName)
            {
                _firstName = firstName;
                _lastName = lastName;
            }

            public string FirstName
            {
                get { return _firstName; }
            }

            public string LastName
            {
                get { return _lastName; }
            }

            /// <summary>
            /// Determines whether the specified <see cref="T:System.Object"/> is equal to the current <see cref="T:System.Object"/>.
            /// </summary>
            /// <returns>
            /// true if the specified <see cref="T:System.Object"/> is equal to the current <see cref="T:System.Object"/>; otherwise, false.
            /// </returns>
            /// <param name="obj">The <see cref="T:System.Object"/> to compare with the current <see cref="T:System.Object"/>. </param><exception cref="T:System.NullReferenceException">The <paramref name="obj"/> parameter is null.</exception><filterpriority>2</filterpriority>
            public override bool Equals(object obj)
            {
                if (obj == this)
                    return true;

                if (obj is ComplexIdClass)
                {
                    ComplexIdClass o = (ComplexIdClass) obj;
                    return o.LastName == LastName && o.FirstName == FirstName;
                }

                return false;
            }

            /// <summary>
            /// Serves as a hash function for a particular type. 
            /// </summary>
            /// <returns>
            /// A hash code for the current <see cref="T:System.Object"/>.
            /// </returns>
            /// <filterpriority>2</filterpriority>
            public override int GetHashCode()
            {
                return (FirstName + "#" + LastName).GetHashCode();
            }
        }
    }
}
