﻿using System;
using System.Collections;
using System.Collections.Generic;
using FT.Architecture.Utils.Generator;
using NUnit.Framework;

namespace FT.Architecture.Tests.Utils
{
    public abstract class RandomDataServiceTests
    {
        private readonly RandomDataService systemUnderTest;

        protected RandomDataServiceTests()
        {
            systemUnderTest = new RandomDataService();
        }

        private static bool CheckThatListDoesntContainSameValues(IList list)
        {
            for (int i = 1; i < list.Count; i++)
            {
                if (list[i] != list[i - 1])
                {
                    return true;
                }
            }

            return false;
        }

        [TestFixture]
        public class When_Generating_Random_Data : RandomDataServiceTests
        {
            [Test]
            public void Getting_Random_First_Names_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<string>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetFirstName());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Last_Names_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<string>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetLastName());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Ages_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<int>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetAge());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Birth_Date_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<DateTime>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetBirthday());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Email_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<string>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetEmail());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Phone_Number_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<string>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetPhoneNumber());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Address_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<string>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetAddress());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_City_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<string>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetCity());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_PostCode_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<string>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetPostCode());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Dates_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<DateTime>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetDate());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Dates_With_Filters_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<DateTime>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetDate(new DateTime(2000, 1, 1), new DateTime(2010, 1, 1)));
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Enum_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<DayOfWeek>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetEnumeration<DayOfWeek>());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Country_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<string>();

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetCountry());
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Object_Should_Not_Always_Return_The_Same_Result()
            {
                // Arrange
                var list = new List<object>();
                var listToChooseFrom = new List<int>();
                for (int i = 0; i < 100; i++)
                {
                    listToChooseFrom.Add(i);
                }

                // Act
                for (int i = 0; i < 10; i++)
                {
                    list.Add(systemUnderTest.GetObject(listToChooseFrom));
                }

                // Assert
                Assert.IsTrue(CheckThatListDoesntContainSameValues(list));
            }

            [Test]
            public void Getting_Random_Different_Object_Should_Not_Return_The_Same_Object_Twice()
            {
                // Arrange
                var listToChooseFrom = new List<int>();
                for (int i = 0; i < 100; i++)
                {
                    listToChooseFrom.Add(i);
                }

                // Act
                var list = systemUnderTest.GetDifferentObjects(90, listToChooseFrom);

                // Assert
                var alreadySelected = new List<int>();
                foreach (var i in list)
                {
                    if (alreadySelected.Contains(i))
                    {
                        Assert.Fail("The same object was found twice in the list");
                    }

                    alreadySelected.Add(i);
                }
            }

            [Test]
            public void Getting_Random_Different_Object_Should_Return_The_Correct_Number_Of_Objects()
            {
                // Arrange
                var listToChooseFrom = new List<int>();
                for (int i = 0; i < 100; i++)
                {
                    listToChooseFrom.Add(i);
                }

                // Act
                var list = systemUnderTest.GetDifferentObjects(90, listToChooseFrom);

                // Assert
                Assert.That(list, Has.Count.EqualTo(90));
            }

            [Test]
            public void Asking_For_More_Different_Objects_Than_Available_Should_Throw_An_Exception()
            {
                // Arrange
                var listToChooseFrom = new List<int>();
                for (int i = 0; i < 100; i++)
                {
                    listToChooseFrom.Add(i);
                }

                // Act & Assert
                Assert.That(() => systemUnderTest.GetDifferentObjects(101, listToChooseFrom), Throws.Exception);
            }
        }
    }
}
