﻿#region Copyright
//       Copyright (c) 2009 - Antoine Jaussoin - http://www.jaussoin.com/blog/
// 
//        This program is free software: you can redistribute it and/or modify
//        it under the terms of the GNU General Public License as published by
//        the Free Software Foundation, either version 3 of the License, or
//        (at your option) any later version.
// 
//        This program is distributed in the hope that it will be useful,
//        but WITHOUT ANY WARRANTY; without even the implied warranty of
//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        GNU General Public License for more details.
// 
//        You should have received a copy of the GNU General Public License
//        along with this program.  If not, see <http://www.gnu.org/licenses/>.
#endregion
using System;
using System.Collections.Generic;
using System.IO;
using FT.Architecture.Utils.Serialisation;
using NUnit.Framework;

namespace FT.Architecture.Tests.Utils
{
    [TestFixture]
    public class SerialisationTests
    {

        [Test]
        public void TestingSerialisationToBytes()
        {
            SerialisationGuineaPig pig = GetGuineaPig();

            byte[] serialisedPig = Serialiser.SerialiseBytes(pig);
            SerialisationGuineaPig deserialisedPig = (SerialisationGuineaPig) Serialiser.DeserialiseBytes(serialisedPig);

            //The two pigs are not the same instance
            Assert.AreNotEqual(pig, deserialisedPig);

            //The deserialised pig should be not null
            Assert.IsNotNull(deserialisedPig);

            //They should have the same name, same age, same number of children
            Assert.AreEqual(pig.Name, deserialisedPig.Name);
            Assert.AreEqual(pig.Age, deserialisedPig.Age);
            Assert.AreEqual(pig.Children.Count, deserialisedPig.Children.Count);

            //The files collection, as it's marked NonSerialized, should be null
            Assert.IsNull(deserialisedPig.Files);

        }

        [Test]
        public void TestingSerialisationToString()
        {
            SerialisationGuineaPig pig = GetGuineaPig();

            string serialisedPig = Serialiser.Serialise(pig);
            SerialisationGuineaPig deserialisedPig = Serialiser.Deserialise <SerialisationGuineaPig>(serialisedPig);

            //The two pigs are not the same instance
            Assert.AreNotEqual(pig, deserialisedPig);

            //The deserialised pig should be not null
            Assert.IsNotNull(deserialisedPig);

            //They should have the same name, same age, same number of children
            Assert.AreEqual(pig.Name, deserialisedPig.Name);
            Assert.AreEqual(pig.Age, deserialisedPig.Age);
            Assert.AreEqual(pig.Children.Count, deserialisedPig.Children.Count);

            //The files collection, as it's marked NonSerialized, should be null
            Assert.IsNull(deserialisedPig.Files);

        }

        private SerialisationGuineaPig GetGuineaPig()
        {
            SerialisationGuineaPig pig = new SerialisationGuineaPig("Bob",27);
            pig.Files.Add(new FileInfo("c:\\"));
            pig.Files.Add(new FileInfo("c:\\"));
            pig.Files.Add(new FileInfo("c:\\"));
            pig.Children.Add(new SerialisationGuineaPig("Robert",26));
            pig.Children.Add(new SerialisationGuineaPig("Jean-Luc",26));
            pig.Children.Add(new SerialisationGuineaPig("René",26));


            var pigChild = new SerialisationGuineaPig("Gontrand", 26);
            pigChild.Children.Add(new SerialisationGuineaPig("Vichnou",21));
            pig.Children.Add(pigChild);

            return pig;
        }
    }

    [Serializable]
    public class SerialisationGuineaPig
    {
        private readonly string _name;
        private readonly int _age;
        private readonly IList<SerialisationGuineaPig> _children;
        [NonSerialized]
        private readonly IList<FileInfo> _files;

        public SerialisationGuineaPig(string name, int age):this()
        {
            _name = name;
            _age = age;
            
        }

        public SerialisationGuineaPig()
        {
            _children = new List<SerialisationGuineaPig>();
            _files = new List<FileInfo>();
        }

        public string Name
        {
            get { return _name; }
        }

        public int Age
        {
            get { return _age; }
        }

        public IList<SerialisationGuineaPig> Children
        {
            get { return _children; }
        }

        public IList<FileInfo> Files
        {
            get { return _files; }
        }
    }
}
